function [Asp,tWithMDDI,Asp0,tNoMDDI,y,y0] = fexpandModSize(endtime,x,x0)
%{
fexpand:  solves free expansion aspect ratio in time. Compare dipole with no dipole. 
INPUTS
endtime = time in ms to end simulation
 x(1) is qr, x(2) is qrd, x(3) is qz, x(4) is qzd

OUTPUTS
Asp = Aspect ratio calculated with MDDI effects
tWithMDDI  = 1D array of timesteps corresponding to Asp
Asp0 = Aspect ratio (for each ixx) calculated without MDDI effects
tNoMDDI = 1D array of timesteps corresponding to Asp0
y and y0 are the arrays from the eqn that give the size and velocity of the components. 
%}

global ASN FLG NUM FRA FRP MAS MAG;

endtau=ceil(endtime/1000*2*pi*FRP); % in tau (t*omega_p)

FLG=1;  %FLG=1: with dipole
[tau1,y]=ode45(@feqnexpand,[0 endtau], [x(1);x(2);x(3);x(4)]);
Asp=y(:,1)./y(:,3);
tWithMDDI=tau1./(2*pi*FRP)*1000;  %ms

FLG=0;  %FLG=1: bo dipole
[tau1,y0]=ode45(@feqnexpand,[0 endtau], [x0(1);x0(2);x0(3);x0(4)]);
Asp0=y0(:,1)./y0(:,3);
tNoMDDI=tau1./(2*pi*FRP)*1000;  %ms